contexttools.InstrumentMark
===========================

.. abjad-lineage:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark

.. autoclass:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.short_instrument_name_markup
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__hash__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark.__repr__
   :noindex:
